
**************************************************
* Code for cleaning AHRI DREAMS nested cohort datasets (AGYW)
* 	PI:				Maryam Shahmanesh
*	Author:			Guy Harling
* 	Started: 		Dec 2019
*	This version: 	Feb 2021

cls
clear all

*
global datLoc "C:\Users\guyha\Datasets\AHRI\DREAMS"
global outLoc "C:\Users\guyha\Dropbox\1 Research\!!Live Projects\AHRI\DREAMS\Dataset building"
*/
/*
global datLoc "C:\Users\rmjlgh0\Datasets\AHRI\DREAMS"
global outLoc "C:\Users\rmjlgh0\Dropbox\1 Research\!!Live Projects\AHRI\DREAMS"
*/

global dat "15Jul2020"

use "$datLoc\AHRI.DREAMS.NestedCohort.StandardizedDataset_all.v1.dta", clear

* net install dm31.pkg			// NB. if not working: try 'search rmiss2' and follow the links
* ssc install missings
*/

qui ds
global lastvar = substr("`r(varlist)'", strrpos("`r(varlist)'", " ") + 1, .)

* iecodebook template using "$outLoc/Dataset build - Dec2019/codebook.xlsx"

* Destring numeric variables captured as strings
# delimit ;
qui ds 
	ie_schoolgrade ie_daysabssch ie_chores_hours 
	dm_partic_stiserv_prog dm_aware_stiserv_prog dm_partic_stiserv_12mts
	dm_stiserv_wasdreams dm_org_stiserv_prog
	dm_participated_when*
	mv*closefriend* mv_mob_use_medic_long mv_mob_number_trips  
	hq_pep_lasttaken hq_frstsmoke_age hq_dayssmoked_mths 
	hq_frstdrink_age hq_daysdrunk_mths hq_more5drinks_day
	hq_frstcannab_age hq_dayscannab_mths
	dr_hsv_test_result dr_hiv_test_result
	/* If keep rapid test results, fix up MH questions once data in */
	sr_age_firstmarr sr_age_husband sr_age_partner sr_agepregnant
	sr_times_pregnant sr_times_birth sr_children_alive_fem
	sr_meth_avoidpreg12mth_0
	srs_agefirstsex srs_partnagefirstsex srs_agesecondsex
	srs_life_numsexpartn srs_12mth_numsexpartn srs_12mth_newsexpartn
	srs_numsexrelat srs_transsex_num 
	srs_recnt1_numsex4wks srs_recnt2_numsex4wks srs_recnt3_numsex4wks
	srs_recnt1_timeago srs_recnt1_lasttime srs_recnt1_personage srs_recent1_agediff
	srs_recnt2_timeago srs_recnt2_lasttime srs_recnt2_personage srs_recent2_agediff
	srs_recnt3_timeago srs_recnt3_lasttime srs_recnt3_personage srs_recent3_agediff
	mv_mob_longest_where
	;
# delimit cr
foreach v in `r(varlist)' {
	qui destring `v', replace
}

* Drop variables we don't need
qui ds ca_visitdate ca_refused_by* ca_proj_noncontact_reas* ca_coordn_approval ///
	ca_premature_comp ca_premature_reas* ca_staffname* ac_assess_result 
foreach v in `r(varlist)' {
	rename `v' z_`v'
}
drop ca_*
drop ac_*
qui ds z_*
foreach v in `r(varlist)' {
	local var = substr("`v'", 3, length("`v'")-2)
	rename `v' `var'
}


*************
*** Section 1. Introductory matter

qui ds cohort round urban_or_rural
foreach v in `r(varlist)' {
	encode `v', gen(`v'2)
	drop `v'
	rename `v'2 `v'	
}
* Flag: If used with male/older female cohorts, rounds are not aligned - use year!
gen 	year = 2017 if round == 1
replace	year = 2018 if round == 2
replace	year = 2019 if round == 3

order cohort round year, after(IIntId)
order urban_or_rural, after(BSIntId)

* Flag: 4 men and 87 with no sex in Baseline round



*************
** Sections 1 & 2. Field operations and Consent

gen 	ic_consent_interv = 1 if ic_indiv_consent_dreams == 1 | ic_indiv_consent_dreams11 == 1 | ic_indiv_consent_dreams11 == 1

/*
* Flag: this variable now superceded by ConsortStatus
lab def lblField 1 "Consented" 2 "No capacity" 3 "Refused" 4 "Premature completion" 5 "Non-contact"
gen		ac_outcome = 1 if ic_consent_interv == 1
replace ac_outcome = 2 if ac_outcome == . & ac_assess_result == 2	// 2 individuals	
replace ac_outcome = 3 if ac_outcome == . & ca_refused_by != . 		// 144 of the 145 listed people converted
replace ac_outcome = 4 if ac_outcome == . & ca_premature_comp == 1 	// 1022 of 1020 converted
replace ac_outcome = 5 if ac_outcome == . & ca_proj_noncontact_reas != . & ca_coordn_approval != 2 // 388 of 295 converted
lab var ac_outcome "Interview final status - calculated"
lab val ac_outcome lblField
order ac_outcome, after(ac_assess_result)
*/

gen 	ac_consortstatus = .
replace	ac_consortstatus = 1 if ConsortStatus == "Deaths"
replace ac_consortstatus = 2 if ConsortStatus == "Premature Completers"
replace ac_consortstatus = 4 if ConsortStatus == "Male participants"
replace ac_consortstatus = 3 if ConsortStatus == "Non-Contacts"
replace ac_consortstatus = 5 if ConsortStatus == "No Mental capacity"
replace ac_consortstatus = 6 if ConsortStatus == "Under/over age"
replace ac_consortstatus = 7 if ConsortStatus == "Refusals"
replace ac_consortstatus = 8 if ConsortStatus == "Enrolled"
lab def lblConst 1 "Died" 2 "Premature completion" 3 "Non-contact" 4 "Ineligible - male" 5 "Ineligible - no capacity" ///
	6 "Ineligible - out of age" 7 "Refusal" 8 "Enrolled"
lab val ac_consortstatus lblConst
lab var ac_consortstatus "Consort Status - participants grouping based on study outcome"


drop ConsortStatus


* Staff member making final contact:
gen ca_staffmember = ca_staffname_attmp1
forvalues i = 2/6 {
	replace ca_staffmember = ca_staffname_attmp`i' if ca_staffname_attmp`i'  != ""
}
replace ca_staffmember = "Zma" if ca_staffmember == "Zandile Mathenjwa"
replace ca_staffmember = "BMk" if ca_staffmember == "BMK" | ca_staffmember == "Bmk"
replace ca_staffmember = "KNg" if ca_staffmember == "Kng" 
replace ca_staffmember = "NFa" if ca_staffmember == "NFA" | ca_staffmember == "Nfa" | ca_staffmember == "Nikeziwe"	
replace ca_staffmember = "KNg" if ca_staffmember == "Kng" 
replace ca_staffmember = "NMb" if ca_staffmember == "Nmb" 
replace ca_staffmember = "SNs" if ca_staffmember == "Sns" 
replace ca_staffmember = "SNt" if ca_staffmember == "Snt" 
replace ca_staffmember = "TDl" if ca_staffmember == "Tdl" 
replace ca_staffmember = "YMi" if ca_staffmember == "Ymi" 
replace ca_staffmember = "ZMa" if ca_staffmember == "Zma" | ca_staffmember == "Zandile Mathenjwa" 
drop ca_staffname*
encode ca_staffmember, gen(ca_staffname)
drop ca_staffmember
lab val ca_staffname 
lab var ca_staffname "Staff member conducting final contact (anonymized)"


replace ic_consent_interv = 2 if ac_consortstatus != 8
lab val ic_consent_interv lblYesNo
lab var ic_consent_interv "Consent for DREAMS interview - calculated"

local stubs hsv hivdbs prevhiv hiv 
foreach v in `stubs' {
	gen 	ic_consent_`v' = 1 if ic_indiv_consent_`v'_1 == 1 | ic_indiv_consent_`v'11 == 1
	replace ic_consent_`v' = .c if ic_consent_`v' == . & ic_consent_interv == 2	
	replace ic_consent_`v' = 2 if ic_consent_`v' == .
	lab val ic_consent_`v' lblYesNo
} 
local stubs specstor fut_test
foreach v in `stubs' {
	gen 	ic_consent_`v' = 1 if ic_indiv_consent_`v'1 == 1 | ic_indiv_consent_`v'5 == 1
	replace ic_consent_`v' = .c if ic_consent_`v' == . & ic_consent_interv == 2	
	replace ic_consent_`v' = 2 if ic_consent_`v' == .
	lab val ic_consent_`v' lblYesNo
} 
lab var ic_consent_hsv 		"Consent for anon HSV-2 test on current DBS - calculated"
lab var ic_consent_hivdbs	"Consent for anon HIV test on current DBS - calculated"
replace ic_consent_hivdbs = .r if round != 3
lab var ic_consent_prevhiv	"Consent for anon HIV test on past DBS - calculated"
replace ic_consent_prevhiv = .r if round != 3

lab var ic_consent_hiv		"Consent for HIV rapid test - calculated"
replace ic_consent_hiv = .r if round == 1
* Flag: Consent asked for HIV rapid test in 2018 (ic_indiv_consent_hiv11 and ic_indiv_consent_hiv_1) but tests not conducted
* replace ic_consent_hiv = .r if round == 2
lab var ic_consent_specstor	"Consent for DBS to be stored - calculated"
lab var ic_consent_fut_test	"Consent for future tests on DBS - calculated"

* Check consistency of inclusion in study frame
cap drop tmp*
gen tmp = 2 - ic_consent_interv
bys IIntId: egen c_ic_consent_total = total(tmp)
lab var c_ic_consent_total "Number of interview consents provided over rounds"
preserve
drop if ic_consent_interv == 2 & round == 1
gen tmp2 = 1 
bys IIntId: egen tmp_count = total(tmp2)
list IIntId tmp_count pd_sex if tmp_count < 3
* Flag: 119220 responds in baseline, never seen again
drop tmp*
restore
order ic_consent_*, before(ie_inschool)

qui ds ie_inschool-$lastvar, has(type numeric)
foreach v in `r(varlist)' {
	qui replace `v'= .c if ic_consent_interv == 2
}
qui ds ie_inschool-$lastvar, has(type string)
foreach v in `r(varlist)' {
	qui replace `v'= ".No consent" if ic_consent_interv == 2
}

*****************************************************
** Add .r for variables not present in whole rounds

*Not in round 1
qui ds ie_prev_inschool_state ie_reas_leave_school_* ie_mainreas_leave_school ie_granttype_* ///
	dm_participated* mv_number_closefriend mv_closefriend_mal ms_* hq_imprt_feats_* ///
	sr_children_alive_fem srs_condomless_1month srs_condomless12months  ///
	dm_*finserv* dm_*finskill* dm_*faclbase* dm_*democond* dm_*pepserv* ///
	, has(type numeric)
foreach v in `r(varlist)' {
	qui replace `v' = .r if `v' == . & round == 1
}
qui ds ms_* ie_prev_inschool_state ie_reas_leave_school_* ie_granttype_* ///
	dm_participated* mv_number_closefriend mv_closefriend_mal ms_* hq_imprt_feats_* ///
	sr_children_alive_fem srs_condomless_1month srs_condomless12months  ///
	dm_*finserv* dm_*finskill* dm_*faclbase* dm_*democond* dm_*pepserv* ///
	, has(type string)
foreach v in `r(varlist)' {
	qui replace `v' = ".Question not in round" if `v' == "" & round == 1
}
* Not in rounds 2 and 3 
qui ds ie_wasabstsch ie_granttype ie_worked_7days ie_other_chores ie_paid_work_12mths ///
	dm_willingprovideid dm_*finlitera* dm_*savegroup* dm_*violprev_* dm_*vocatskills* ///
	dm_*_microfin* dm_*mobiletest* dm_*hometest* dm_*familytest* dm_*linkart* dm_*artadhere* ///
	dm_*violprevnt* dm_*cashagyw* dm_*schoolsup* dm_*shuga* ///
	, has(type numeric)
foreach v in `r(varlist)' {
	qui replace `v' = .r if `v' == . & round != 1
}
qui ds ie_wasabstsch ie_granttype ie_worked_7days ie_other_chores ie_paid_work_12mths ///
	dm_willingprovideid dm_*finlitera* dm_*savegroup* dm_*violprev_* dm_*vocatskills* ///
	dm_*_microfin* dm_*mobiletest* dm_*hometest* dm_*familytest* dm_*linkart* dm_*artadhere* ///
	dm_*violprevnt* dm_*cashagyw* dm_*schoolsup* dm_*shuga* ///
	, has(type string)
foreach v in `r(varlist)' {
	qui replace `v' = ".Question not in round" if `v' == "" & round == 1
}
* Not in rounds 1 and 2
qui ds mv_no_friends_advice mv_no_friend_person_advice mv_other_friends_advice mv_first_person_advice ///
	mv_mob_* mv_general_hopeful-mv_change_nothing or_* hq_reas_no_hivtest sr_new_married_moved ///
	srs_recnt1_sex_someone mh_* dm_*thethana* ///
	, has(type numeric)
foreach v in `r(varlist)' {
	qui replace `v' = .r if `v' == . & round != 3
}
qui ds mv_first_person_advice_oth mv_mob_last_place_visited mv_mob* or_* hq_reas_no_hivtestoth ///
	mh_* dm_*thethana* , has(type string)
foreach v in `r(varlist)' {
	qui replace `v' = ".Question not in round" if `v' == "" & round != 3
}
* Not in all rounds (questions only for males
qui ds dm_*maletest* dm_*malecircum* , has(type numeric)
foreach v in `r(varlist)' {
	qui replace `v' = .r if `v' == . 
}
qui ds dm_*maletest* dm_*malecircum* , has(type string)
foreach v in `r(varlist)' {
	qui replace `v' = ".Question not in round" if `v' == "" 
}

*************
** Section 3. Education, Economics and Nutrition

* drop ie_prev_inschool_state  - preloaded variable checked as ie_inschool
destring 	ie_schoolgrade, replace
replace		ie_schoolgrade = .n if ie_inschool == 2 & ie_schoolgrade == .

* Screener not asked in waves 2 and 3
replace 	ie_wasabstsch = .n 	if ie_wasabstsch == . & ie_inschool == 2 | ie_inschool > 91
replace 	ie_wasabstsch = 2 	if ie_wasabstsch == . & ie_daysabssch == 0
replace 	ie_wasabstsch = 1 	if ie_wasabstsch == . & ie_daysabssch > 0 & !missing(ie_daysabssch)

qui ds ie_schabsreas_*
foreach v in `r(varlist)' {
	replace `v' = .n 	if `v' == . & ie_wasabstsch != 1 
	replace `v' = 2 	if `v' == . & ie_wasabstsch == 1 
}
replace ie_absschreasoth = ".Not applicable" if ie_schabsreas_96 != 1 & ie_absschreasoth == ""

* FLAG: ie_reas_leave_school_* hidden in round 3
qui ds ie_reas_leave_school_1-ie_reas_leave_school_96
foreach v in `r(varlist)' {		
	replace `v' = .r 	if `v' == . & round == 3
	replace `v' = .n 	if `v' == . & (ie_prev_inschool_state != 1 | ie_inschool != 2)
	replace `v' = 2 	if `v' == . & ie_inschool == 2
}
replace ie_reas_leave_school_oth = ".Not applicable" if ie_reas_leave_school_96 != 1 & ie_reas_leave_school_oth == ""

drop ie_mainreas_leave_school		// never asked

replace ie_othincome = 93 if ie_othincome == .
replace ie_incomeoth = ".Not applicable" if ie_othincome != 1 & ie_incomeoth == ""

** Grants: Round 1 asks 'specify one', Rounds 2/3 'specify all that apply'
foreach i in 1 2 3 4 6 96 {
	replace ie_granttype_`i' = 93 if ie_granttype_`i' == . & ie_granttype == 93 | ie_granttype_93 == 93 
	replace ie_granttype_`i' = 98 if ie_granttype_`i' == . & ie_granttype == 98	| ie_granttype_93 == 98 
}
replace ie_grantoth = ".Not applicable" if ie_granttype_96 != 96 & ie_grantoth == ""
drop ie_granttype_93 ie_granttype_98

* Chores: tidying pre-question into main one
replace ie_chores_hours = ie_chores_time if ie_chores_time > 89 & !missing(ie_chores_time)
replace ie_chores_hours = 93 if ie_chores_time == 2 | (ie_chores_hours == . & ie_chores_time == .)
drop 	ie_chores_time

* Items owned - tidy school-based variables
replace ie_items_own03 = .n if (ie_items_own03 == . | ie_items_own03 == 97) & ie_inschool != 1
replace ie_items_own03 = .n if ie_items_own03 == 2 & ie_inschool != 1 
replace ie_items_own05 = .n if (ie_items_own05 == . | ie_items_own05 == 97) & ie_inschool != 1
replace ie_items_own05 = .n if ie_items_own05 == 2 & ie_inschool != 1 

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 96 {
	replace ie_dialyneeds_source_`i' = .n if ie_dialyneeds_source_`i' == . & ie_dailyneeds_spend != 1  
	replace ie_dialyneeds_source_`i' = 1 if ie_dialyneeds_source_`i' == `i' 
	replace ie_dialyneeds_source_`i' = 2 if ie_dialyneeds_source_`i' == .  & ie_dailyneeds_spend == 1 
}
replace ie_dailyn_source_oth = ".Not applicable" if ie_dialyneeds_source_96 != 1 & ie_dailyn_source_oth == ""

foreach i in 0 1 2 3 4 5 6 7 8 9 10 96 {
	replace ie_spenton_12mths_`i' = .n if ie_spenton_12mths_`i' == . & ie_dailyneeds_spend != 1  
	replace ie_spenton_12mths_`i' = 1 if ie_spenton_12mths_`i' == `i' 
	replace ie_spenton_12mths_`i' = 2 if ie_spenton_12mths_`i' == .  
}
replace ie_spenton_oth = ".Not applicable" if ie_spenton_12mths_96 != 1 & ie_spenton_oth == ""

replace ie_spenton_decide = .n if ie_dailyneeds_spend != 1 & ie_spenton_decide == .
* Flag: Some non-spenders have a decisionmaker: tab ca_visitdate if !missing(ie_spenton_decide) & ie_dailyneeds_spend > 1
replace ie_spentdecide_oth = ".Not applicable" if ie_spenton_decide != 96 & ie_spentdecide_oth == ""
replace ie_access_savings = .n if ie_saved_money_12mths != 1 & ie_access_savings == . 

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 96 {
	replace ie_saving_for_`i' = .n 	if ie_saving_for_`i' == . & ie_saved_money_12mths != 1
	replace ie_saving_for_`i' = 1 	if ie_saving_for_`i' == `i' 
	replace ie_saving_for_`i' = 2 	if ie_saving_for_`i' == .  
}
replace ie_saving_for_oth = ".Not applicable" if ie_saving_for_96 != 1 & ie_saving_for_oth == ""

replace ie_has_written_budget = .n if ie_has_budget != 1 & ie_has_written_budget == .
replace ie_follow_budget = .n if ie_has_budget != . & ie_follow_budget == .

foreach i in 1 2 3 96 {
	replace ie_budget_type_`i' = .n if ie_budget_type_`i' == . & ie_has_budget != 1
	replace ie_budget_type_`i' = 1 	if ie_budget_type_`i' == `i' 
	replace ie_budget_type_`i' = 98	if ie_budget_type_98 == 98 
	replace ie_budget_type_`i' = 2 	if ie_budget_type_`i' == .  
}
drop ie_budget_type_98

foreach i in 1 2 3 4 5 6 7 8 9 {
	replace ie_wayof_saving_`i' = .n 	if ie_wayof_saving_`i' == . & ie_saved_money_12mths != 1
	replace ie_wayof_saving_`i' = 1 	if ie_wayof_saving_`i' == `i' 
	replace ie_wayof_saving_`i' = 98	if ie_wayof_saving_98 == 98 
	replace ie_wayof_saving_`i' = 93	if ie_wayof_saving_93 == 98 
	replace ie_wayof_saving_`i' = 2 	if ie_wayof_saving_`i' == .  
}
drop ie_wayof_saving_93 ie_wayof_saving_98

replace ie_foodfreqskip = .n if ie_foodfreq != 1 & ie_foodfreqskip == .



*************
** Section 4. DREAMS


foreach i in 1 2 3 4 5 6 7 8 9 96 {
	replace dm_source_`i' = .n 	if dm_source_`i' == . & dm_aware_dreams != 1
	replace dm_source_`i' = 1 if dm_source_`i' == `i' 
	replace dm_source_`i' = 2 	if dm_source_`i' == .
}
replace dm_source_other = ".Not applicable" if dm_source_96 != 96 & dm_source_other == ""
* Flag: One interviewer entereed 'ahri' for almost everyone in round 3 - 39 people say 'ahri' despite not saying yes to 96...
*    bys dm_source_96:  tab dm_source_other round, miss

replace dm_invited = .n if dm_aware_dreams != 1 & dm_invited == .

replace dm_participated = .n if dm_aware_dreams != 1 & dm_participated == .
foreach i in 2016 2017 2018 {
	replace dm_participated_when_`i' = 1 if dm_participated_when_`i' == `i'
	replace dm_participated_when_`i' = .n if dm_participated_when_`i' == . & dm_aware_dreams != 1
	replace dm_participated_when_`i' = 2 if dm_participated_when_`i' == . 
}	

replace dm_have_identifier = .n if dm_have_identifier == . & (dm_aware_dreams != 1 | dm_invited != 1)
replace dm_willingprovideid = .n if dm_willingprovideid == . & dm_have_identifier != 1

* Schooledu question: skip pattern inconsistent (only asked if 'inschool' in round 1/3 but to all in round 2)
* Flag: I have standardized to skip all those not in school (remove results in round 2) for **participation** only 
qui ds dm_*schooledu*, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n 				if ie_inschool == 2 
}
qui ds dm_*schooledu*, has(type string)
foreach v in `r(varlist)' {
	replace `v' = ".Not applicable" if ie_inschool == 2 
}

* Flag: Round 1: awareness before participation; Round 2/3: participation before awareness
	
rename dm_partic_counsl_prv_12mts dm_partic_counsl_prov_12mts
qui ds dm_partic_*_prog
foreach v in `r(varlist)' {
	local act_len = length("`v'") - 15
	local activity = substr("`v'", 11, `act_len')
	if "`activity'" != "shuga" {
		di "`activity'"
		replace dm_partic_`activity'_prog 	= 2 if dm_aware_`activity'_prog == 2 & round == 1 & dm_partic_`activity'_prog == .
		replace dm_aware_`activity'_prog 	= 1 if dm_partic_`activity'_prog == 1 & round > 1 & dm_aware_`activity'_prog == .
		replace dm_partic_`activity'_12mts 	= 2 if dm_partic_`activity'_prog == 2 & dm_partic_`activity'_12mts == . 
		replace dm_`activity'_wasdreams  	= .n if dm_partic_`activity'_12mts != 1 & dm_`activity'_wasdreams == .
		replace dm_org_`activity'_prog  	= .n if dm_org_`activity'_prog == . & (dm_`activity'_wasdreams != 1 & dm_`activity'_wasdreams != 2)
		replace dm_org_`activity'_oth 		= ".Not applicable" if dm_org_`activity'_prog != 96	& dm_org_`activity'_oth == ""	
	}
}
* MTV Shuga looks a bit different
qui ds dm_partic_shuga_prog-dm_shuga_source_96
foreach v in `r(varlist)' {
	replace `v' = .n if round != 1 & `v' == .
}
replace dm_partic_shuga_prog = 2 if dm_aware_shuga_prog == 2 & round == 1 & dm_partic_shuga_prog == . 
replace dm_aware_shuga_prog = 1 if dm_partic_shuga_prog == 1 & round > 1 & dm_aware_shuga_prog == . 
replace dm_partic_shuga_12mts = 2 if dm_partic_shuga_prog == 2 & dm_partic_shuga_12mts == .

qui ds dm_shuga_source_1-dm_shuga_source_5 dm_shuga_source_96
foreach i in 1 2 3 4 5 96 {
	replace dm_shuga_source_`i' = 93 if dm_shuga_source_93 == 93 & dm_shuga_source_`i' == . 
	replace dm_shuga_source_`i' = .n if dm_partic_shuga_prog == 2 & dm_shuga_source_`i' == . 
	replace dm_shuga_source_`i' = 2 if dm_partic_shuga_prog == 1 & dm_shuga_source_`i' == .  
}
replace dm_shuga_source_oth = ".Not applicable" if dm_shuga_source_96 != 96


/*
qui ds dm_*finserv*, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & ie_inschool != 1
}
*/

qui ds dm_aware*
foreach v in `r(varlist)' {
	di "`v'"
	tab `v' round, miss
}



*************
** Section 5. Mediating variables

* Friends and safe spaces 
replace mv_privmeetregul_fem = .n 	if mv_privmeetregul_fem == . & mv_privmeetplace_fem != 1 
replace mv_closefriend_fem = .n 	if mv_closefriend_fem == . & mv_number_closefriend == 0
replace mv_closefriend_mal = .n 	if mv_closefriend_mal == . & mv_number_closefriend == 0

replace mv_no_friends_advice = .n 		if mv_no_friends_advice == . & (mv_number_closefriend > 0 &  !missing(mv_number_closefriend))
replace mv_no_friend_person_advice = .n if mv_no_friend_person_advice == . & mv_no_friends_advice != 1

replace mv_other_friends_advice = .n if (mv_number_closefriend == 0 | round != 3) & mv_other_friends_advice == .
replace mv_first_person_advice = .n if mv_other_friends_advice ! =1 & mv_first_person_advice == .

replace mv_first_person_advice_oth = ".Not applicable" if mv_no_friend_person_advice != 96 & mv_first_person_advice_oth == ""


* Mobility questions
qui ds mv_mob*, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if round != 3 & `v' == .
}
qui ds mv_mob*, has(type string)
foreach v in `r(varlist)' {
	replace `v' = ".Not applicable" if round != 3 & `v' == ""
}

replace mv_mob_last_place_visited 	= ".Not applicable" if mv_mob_moved_away != 1 & mv_mob_last_place_visited == ""
replace mv_mob_last_where 			= .n if mv_mob_moved_away != 1 & mv_mob_last_where  == . 
replace mv_mob_last_whereoth 		= ".Not applicable" if mv_mob_last_where != 96 & mv_mob_last_whereoth == ""
replace mv_mob_timein_lastplace 	= .n if mv_mob_moved_away != 1 & mv_mob_timein_lastplace == .
replace mv_mob_last_longest_trip 	= .n if mv_mob_moved_away != 1 & mv_mob_last_longest_trip == .

replace mv_mob_live_with_last		= .n if mv_mob_moved_away != 1 & mv_mob_live_with_last  == . 
replace mv_mob_live_with_last_oth 	= ".Not applicable" if mv_mob_live_with_last != 96 & mv_mob_live_with_last_oth == ""
replace mv_mob_use_medic_last 		= .n if mv_mob_moved_away != 1 & mv_mob_use_medic_last  == . 

foreach v in mv_mob_longest_name mv_mob_longest_trip mv_mob_longest_whereoth {
	replace `v' = ".Not applicable" if mv_mob_last_longest_trip != 2 & `v' == ""
}
foreach v in mv_mob_live_with_long mv_mob_use_medic_long {
	replace `v' = .n if mv_mob_last_longest_trip != 2 & `v' == .
}
* Flag: Need to tidy mv_mob_longest_trip to a time period
replace mv_mob_longest_whereoth = ".Not applicable" if mv_mob_longest_whereoth == "" & mv_mob_longest_where != 96

foreach i in 1 2 3 4 5 7 96 {
	replace mv_mob_reas_visit_last_`i' = .n if mv_mob_reas_visit_last_`i' == . & mv_mob_moved_away != 1 
	replace mv_mob_reas_visit_last_`i' = 1 	if mv_mob_reas_visit_last_`i' == `i'
	replace mv_mob_reas_visit_last_`i' = 2 	if mv_mob_reas_visit_last_`i' == . & mv_mob_moved_away == 1 
}
replace mv_mob_reas_visit_lastoth = ".Not applicable" if mv_mob_reas_visit_last_96 != 96 & mv_mob_reas_visit_lastoth == ""
drop mv_mob_reas_visit_last		// empty varible, was probably a multi-option string originally
order mv_mob_reas_visit_lastoth, after(mv_mob_reas_visit_last_96)

foreach i in 1 2 3 4 6 96 {
	replace mv_mob_reas_visit_long_`i' = .n if mv_mob_last_longest_trip != 2 & mv_mob_reas_visit_long_`i' == .
	replace mv_mob_reas_visit_long_`i' = 2 	if mv_mob_last_longest_trip == 2 & mv_mob_reas_visit_long_`i' == .  
}
drop mv_mob_reas_visit_long		// empty varible, was probably a multi-option string originally

replace mv_mob_reas_visit_longoth = ".Not applicable" if mv_mob_reas_visit_long_96 != 96 & mv_mob_live_with_long_oth == ""
replace mv_mob_live_with_long_oth = ".Not applicable" if mv_mob_live_with_long != 96 & mv_mob_live_with_long_oth == ""

replace mv_mob_number_trips = .n if mv_mob_moved_away != 1 & mv_mob_number_trips == .

replace mv_mob_longest_where = .n if mv_mob_longest_where == . & (mv_mob_moved_away != 1 | mv_mob_last_longest_trip != 2)

qui ds or_* , has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .r if !missing(`v') & round == 2		// drop 110 responses from round 2 for consistency
}
replace or_type_trouble_police = .n if or_type_trouble_police == . & or_trouble_police != 1
replace or_type_trouble_police_oth = ".Not applicable" if or_type_trouble_police_oth == "" & or_type_trouble_police != 96
replace or_type_trouble_police_oth = ".Question not in round" if or_type_trouble_police_oth == "None" & round == 2
replace or_part_of_gang = 2 if or_part_of_gang == . & round == 3



*************
** Section 6. MTV Shuga

* Not asked in round 1

replace ms_watch_tv_where 		= .n if ms_watch_tv_freq == 1 & ms_watch_tv_where == .
replace ms_watch_tv_where_oth 	= ".Not applicable" if ms_watch_tv_where != 96 & ms_watch_tv_where_oth == ""
replace ms_cntrl_tv_remote 		= .n if ms_watch_tv_where != 1 & ms_cntrl_tv_remote == .
replace ms_cntrl_tv_remote_oth 	= ".Not applicable" if ms_cntrl_tv_remote != 96 & ms_cntrl_tv_remote_oth == ""

replace ms_ever_heard_of_shuga = .n if ms_ever_watched_shuga != 2 & ms_ever_heard_of_shuga == .

qui ds ms_ever_watched_source ms_which_series_of_shuga
foreach v in `r(varlist)' {
	replace `v' = .n if ms_ever_watched_shuga != 1 & `v' == .

}
replace ms_ever_watched_sourc_oth 	= ".Not applicable" if ms_ever_watched_source != 96 & ms_ever_watched_sourc_oth == ""
replace ms_which_series_oth 		= ".Not applicable" if ms_which_series_of_shuga != 96 & ms_which_series_oth == ""

qui ds ms_num_times_watched ms_knowl* ms_talked_about_shuga
foreach v in `r(varlist)' {
	replace `v' = .n if ms_which_series_of_shuga != 1 & ms_which_series_of_shuga != 3 & `v' == .

}
foreach i in 1 3 4 5 {
	replace ms_talked_to_who_`i' = 2  if ms_talked_to_who_`i' == . & (ms_talked_about_shuga == 1 | ms_talked_about_shuga == 3)
	replace ms_talked_to_who_`i' = .n if ms_talked_to_who_`i' == . & ms_talked_about_shuga != 1 & ms_talked_about_shuga != 3
}
* Flag: option 2 (sexual partner) gathered zero responses, so not included
gen 	ms_talked_to_who_2 = ms_talked_to_who_1
replace ms_talked_to_who_2 = 2 if ms_talked_to_who_2 == 1

qui ds ms_gbv_report_it-ms_intend_start_prep
foreach v in `r(varlist)' {
	replace `v' = .n if ms_ever_watched_shuga != 1 & `v' == .

}
qui ds ms_charid_*, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if ms_which_series_of_shuga != 1 & `v' == .
}
replace ms_charid_your_rel_charac = .n if ms_charid_your_rel_charac == . & ms_charid_had_rel_charac == 1 | ms_charid_had_rel_charac == 93
replace ms_charid_your_fav_oth = ".Not applicable" if ms_charid_your_rel_charac != 96 & ms_charid_your_fav_oth == ""
replace ms_socm_fav_media_oth = ".Not applicable" if ms_socm_fav_media_platf != 96 & ms_socm_fav_media_oth == ""

foreach i in 1 2 3 4 5 6 7 8 96 {
	replace ms_socm_use_phone_for_`i' = 93 if ms_socm_use_phone_for_93 == 93
	replace ms_socm_use_phone_for_`i' = 2  if ms_socm_use_phone_for_`i' == .
}
drop ms_socm_use_phone_for_93
replace ms_socm_use_phone_oth = ".Not applicable" 	if ms_socm_use_phone_oth == "" & ms_socm_use_phone_for_96 != 96
* Flag: ms_socm_use_phone_oth has single character import issue
replace ms_know_hiv_prevent_oth = ".Not applicable" if ms_know_hiv_prevent_oth == "" & ms_know_hiv_prevent_96 != 96




*************
** Section 7. General health

* replace hq_hiv_imptest = .n if hq_hiv_imptest == . & hq_hiv_knwstatus != 1
foreach i in 1 2 3 4 96 {
	replace hq_hiv_imptest_`i' = .n if hq_hiv_imptest_`i' == . & hq_hiv_knwstatus != 1 
}
replace hq_hiv_imptestoth = ".Not applicable" if hq_hiv_imptest_96 != 96 & hq_hiv_imptestoth == ""
* Flag: there are 791 responses here that will need coding!

replace hq_reas_no_hivtest = .n if hq_recv_hivresult != 2 & hq_reas_no_hivtest == . & hq_reas_no_hivtest == .
replace hq_reas_no_hivtest = .n if round != 3 & hq_reas_no_hivtest == .
replace hq_reas_no_hivtestoth = ".Not applicable" if hq_reas_no_hivtest != 96 & hq_reas_no_hivtestoth == ""

replace hq_hiv_testwhere = .n if hq_recv_hivresult != 1 & hq_hiv_testwhere == . 
replace hq_hiv_testwhereoth = ".Not applicable" if hq_hiv_testwhere != 96 & hq_hiv_testwhereoth == ""

qui ds hq_hiv_testoffered hq_hiv_testreas hq_hiv_priorcounsel hq_pos_hivresult hq_lastneghivresult
foreach v in `r(varlist)' {
	replace `v' = .n if hq_recv_hivresult != 1 & `v' == .
}
* Flag: 45 people say never received result, but asked if ever tested positive (round 1)
replace hq_pos_hivresult = .n if !missing(hq_pos_hivresult) & hq_recv_hivresult != 1

lab def lblOneYear 4 "Have never tested", modify
replace hq_hiv_testreasoth = ".Not applicable" if hq_hiv_testreas != 96 & hq_hiv_testreasoth == ""

qui ds hq_firstposresult hq_refertreatm hq_prev_arttreat hq_art_takenmtct hq_curr_arttreat 
foreach v in `r(varlist)' {
	replace `v' = .n if hq_pos_hivresult != 1 & `v' == .
}
qui ds hq_start_arttreat hq_art_takenstop hq_recvfrom_arttreat hq_art_exttimetake
foreach v in `r(varlist)' {
	replace `v' = .n if hq_prev_arttreat != 1 & `v' == .
}
replace hq_art_reastakenstop = ".Not applicable" if hq_art_reastakenstop == "" & hq_art_takenstop != 1
replace hq_heardof_art = .n if (hq_pos_hivresult != 2 & hq_pos_hivresult >  90) & hq_heardof_art == .

replace hq_heardof_art = .n if hq_heardof_art == . & hq_pos_hivresult != 2

qui ds hq_pep_knowplaces hq_pep_taken
foreach v in `r(varlist)' {
	replace `v' = .n if hq_pep_heardof != 1 & `v' == .
}
qui ds hq_pep_lasttaken hq_pep_lasttakenunit hq_pep_getwhere
foreach v in `r(varlist)' {
	replace `v' = .n if hq_pep_taken != 1 & `v' == .
}
* Flag: hq_pep_lasttaken - issues with year values, needs cleaning further
replace hq_pep_takenwhy = ".Not applicable" if hq_pep_takenwhy == "" & hq_pep_taken != 1

qui ds hq_prep_offered hq_prep_currtaken
foreach v in `r(varlist)' {
	replace `v' = .n if hq_prep_knowof != 1 & `v' == .
}
qui ds hq_prep_heardwhere
foreach v in `r(varlist)' {
	replace `v' = ".Not applicable" if hq_prep_knowof != 1 & `v' == ""
}
replace hq_prep_taken12mths = .n if hq_prep_offered !=1 & hq_prep_taken12mths == .
replace hq_prep_takenfromdreams = .n if hq_prep_taken12mths != 1 & hq_prep_takenfromdreams == .
replace hq_prep_currtaken = .n if hq_prep_currtaken == . & hq_prep_taken12mths != 1 & round != 1
replace hq_prep_currtaken = .n if hq_prep_currtaken == . & hq_prep_knowof != 1 & round == 1
* Flag: Different skip pattern in wave 1 (hq_prep_knowof) vs wave 2/3 (hq_prep_taken12mths)
replace hq_prep_reasnottaken = .n if hq_prep_currtaken != 0 & hq_prep_reasnottaken == .
replace hq_prep_reasnototh = ".Not applicable" if hq_prep_reasnottaken != 96 & hq_prep_reasnototh == ""

qui ds hq_prep_getwhere hq_prep_takendaily hq_prep_takentime hq_prep_takensupp
foreach v in `r(varlist)' {
	replace `v' = .n if hq_prep_currtaken != 1 & `v' == .
}
replace hq_prep_getwhereoth_in	= ".Not applicable" if hq_prep_getwhereoth_in == "" & hq_prep_getwhere != 96
replace hq_prep_getwhereoth_out	= ".Not applicable" if hq_prep_getwhereoth_out == "" & hq_prep_getwhere != 11
replace hq_prep_getwhereoth_org	= ".Not applicable" if hq_prep_getwhereoth_org == "" & hq_prep_getwhere != 996

* drop hq_prep_takenstrug		// empty variable
foreach i in 2 3 4 5 6 7 8 96 {
	cap gen hq_prep_takenstrug_`i' = .
	replace hq_prep_takenstrug_`i' = 1 	if hq_prep_takenstrug_`i' == `i'
	* replace hq_prep_takenstrug_`i' = 93 if hq_prep_takenstrug_`i' == . & hq_prep_takenstrug_93 == 93 
	replace hq_prep_takenstrug_`i' = 2 	if hq_prep_takenstrug_`i' == . & hq_prep_currtaken == 1
	replace hq_prep_takenstrug_`i' = .n if hq_prep_takenstrug_`i' == . & hq_prep_currtaken != 1
	order hq_prep_takenstrug_`i', before(hq_prep_takenstrugpoth )
}
replace hq_prep_takenstrugpoth = ".Not applicable" if hq_prep_takenstrugpoth == "" & hq_prep_takenstrug_96 != 96
* drop hq_prep_takenstrug_93

replace hq_prep_freq_med_take = .n if hq_prep_freq_med_take == . & round == 1
qui ds hq_imprt_feats_*
foreach v in `r(varlist)' {
	replace `v' = .n if round == 1 & `v' == .
}

qui ds hq_frstsmoke_age hq_dayssmoked_mths hq_smokless_tabac
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & hq_eversmoke != 1
}
replace hq_frstsmoke_age = 15 if hq_frstsmoke_age == 151
qui ds hq_frstdrink_age hq_daysdrunk_mths hq_more5drinks_day
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & hq_everdrink != 1
}
replace hq_frstdrink_age = 13 if hq_frstsmoke_age == 130
replace hq_frstdrink_age = 18 if hq_frstsmoke_age == 181
replace hq_frstdrink_age = 15 if hq_frstsmoke_age == 1500

qui ds hq_frstcannab_age hq_dayscannab_mths
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & hq_everuse_cannab != 1
}
foreach i in 2 3 4 5 6 7 96 {
	replace hq_usedoth_drugs_`i' = 93 if hq_usedoth_drugs_`i' == . & hq_usedoth_drugs_93 == 93
}
replace hq_inhal_oth = ".Not applicable" if hq_inhal_oth == "" & hq_usedoth_drugs_3 != 3
replace hq_clubdrug_oth = ".Not applicable" if hq_clubdrug_oth == "" & hq_usedoth_drugs_7 != 7
* replace hq_overcount_oth = ".Not applicable" if hq_overcount_oth == "" & hq_usedoth_drugs_8 != 8
replace hq_overcount_oth = ".Not applicable" if hq_overcount_oth == "" 		// no-one in this dataset with value=8
* replace hq_perscribtion_oth = ".Not applicable" if hq_perscribtion_oth == "" & hq_usedoth_drugs_9 != 9
replace hq_perscribtion_oth = ".Not applicable" if hq_perscribtion_oth == "" 		// no-one in this dataset with value=9
replace hq_othdrug_oth = ".Not applicable" if hq_othdrug_oth == "" & hq_usedoth_drugs_96 != 96




*************
** Section 8. Sexual reproductive health

* Marriage

drop 	sr_prev_currently_married		// empty variable
replace sr_currently_cohabiting = .n if sr_currently_cohabiting == . & round == 1
replace sr_currently_cohabiting = .n if sr_currently_cohabiting == . & sr_currently_married == 1
replace sr_evermarried = .n if sr_evermarried == . & (sr_currently_married != 2 |  sr_currently_cohabiting == .n)
replace	sr_marriage_type = .n if sr_marriage_type == . & (sr_evermarried == 2 | sr_evermarried == .n)
replace sr_marriage_typoth = ".Not applicable" if sr_marriage_typoth == "" & sr_marriage_type != 96
replace sr_new_married_moved = .n if sr_new_married_moved == . & (sr_marriage_type == .n | round == 1)
replace sr_live_husband = .n if sr_live_husband == . & sr_marriage_type == .n
replace sr_age_firstmarr = sr_share_agefirstmarr if sr_share_agefirstmarr > 89 & sr_share_agefirstmarr < 100
replace sr_age_firstmarr = .n if sr_age_firstmarr == . & sr_marriage_type == .n
replace sr_age_husband = sr_share_agehusband if sr_share_agehusband > 89 & sr_share_agehusband < 100
replace sr_age_husband = sr_age_partner if sr_age_husband == . & sr_age_partner < 90
replace sr_age_husband = .n if sr_age_husband == . & sr_marriage_type == .n
replace sr_marriage_reas = .n if sr_marriage_reas == . & (round > 1 | sr_marriage_type == .n)
replace sr_marriage_reasoth = ".Not applicable" if sr_marriage_reasoth == "" & sr_marriage_reas != 96

* Pregnancy

replace sr_currpregnant = .e if sr_currpregnant == . & pd_sex != 2
replace sr_everpregnant = .e if sr_everpregnant == . & pd_sex != 2
* Flag: Missing data for 10 women in round 1 due to pd_sex error
* Flag: 6 extra missing values here for round 1
replace sr_pregnant_last_12mths = .n if sr_pregnant_last_12mths == . & round == 1 
replace sr_pregnant_last_12mths = .n if sr_pregnant_last_12mths == . & (sr_currpregnant != 1 | sr_everpregnant != 1)
replace sr_agepregnant = sr_agepregnant if sr_agepregnant > 89 & sr_agepregnant < 100
replace sr_agepregnant = 18 if sr_agepregnant == 1811		// respondent aged 19 now
replace sr_agepregnant = .n 		if sr_agepregnant == . & (sr_currpregnant != 1 | sr_everpregnant != 1)
replace sr_times_pregnant = .n 		if sr_times_pregnant == . & (sr_currpregnant != 1 | sr_everpregnant != 1)
* Flag: 4 people give an age here for sr_times_pregnant 
replace sr_times_birth = .n 		if sr_times_birth == . & (sr_currpregnant != 1 | sr_everpregnant != 1)
tab  sr_times_pregnant sr_times_birth, miss		// Note likely typos here for 11, 21, 27 
replace sr_times_birth = 1 			if sr_times_birth == 11
replace sr_times_birth = 2 			if sr_times_birth == 21 | sr_times_birth == 27  // Assumption that 21 births from 2 pregancies is 2 not 1 births
replace sr_children_alive_fem = .n 	if sr_children_alive_fem == . & (round == 1 | sr_currpregnant != 1 | sr_everpregnant != 1)

replace sr_another_child = .n if sr_another_child == . & sr_currpregnant != 2
replace sr_waitbrf_another = .n if sr_waitbrf_another == . & sr_another_child != 1
replace sr_aftbrth_more = .n if sr_aftbrth_more == . & sr_currpregnant != 1
replace sr_waitbrf_birth = .n if sr_waitbrf_birth == . & sr_aftbrth_more != 1

drop 	sr_share_*	sr_age_partner	// Four variables, data now captured in other response
rename 	sr_age_husband sr_age_partner // Rename to fit with other cohorts later on

foreach i in 1 2 3 4 5 96 {
	replace sr_nomore_children_`i' = .n if sr_nomore_children_`i' == . & (sr_aftbrth_more != 2 & sr_aftbrth_more != 98 & sr_another_child != 2 & sr_another_child != 98)
	replace sr_nomore_children_`i' = 93 if sr_nomore_children_`i' == . & sr_nomore_children_93 == 93
	replace sr_nomore_children_`i' = 98 if sr_nomore_children_`i' == . & sr_nomore_children_98 == 98
}
drop sr_nomore_children_93 sr_nomore_children_98
replace sr_nomore_child_oth = ".Not applicable" if sr_nomore_child_oth == "" & sr_nomore_children_96 != 96

replace sr_partner_more_child = .n if sr_partner_more_child == . & (sr_aftbrth_more != 2 & sr_aftbrth_more != 98 & sr_another_child != 2 & sr_another_child != 98)
replace sr_partner_num_child = .n if sr_partner_num_child == . & sr_partner_more_child != 1

* Contraception

replace sr_areusemeth_avoidpreg = .n if sr_areusemeth_avoidpreg == . & sr_currpregnant != 2
replace sr_notusemeth_avoidpreg = .n if sr_notusemeth_avoidpreg == . & sr_areusemeth_avoidpreg != 2
replace sr_notusemeth_otherspec = ".Not applicable" if sr_notusemeth_otherspec == "" & sr_notusemeth_avoidpreg != 96
foreach i in 0 1 2 3 4 5 6 7 8 9 96 {
	cap gen sr_currmeth_avoidpreg_`i' = .
	replace sr_currmeth_avoidpreg_`i' = .n if sr_currmeth_avoidpreg_`i' == . & sr_areusemeth_avoidpreg != 1
	replace sr_currmeth_avoidpreg_`i' = 93 if sr_currmeth_avoidpreg_`i' == . & sr_currmeth_avoidpreg_93 == 93
}
replace sr_currmeth_otherspec = ".Not applicable" if sr_currmeth_otherspec == "" & sr_currmeth_avoidpreg_96 != 96
replace sr_whatmeth_avoidpreg12mth = .n if sr_whatmeth_avoidpreg12mth == . & pd_sex != 2
foreach i in 0 1 2 3 4 5 6 7 8 9 96 {
	cap gen sr_meth_avoidpreg12mth_`i' = .
	replace sr_meth_avoidpreg12mth_`i' = .n if sr_meth_avoidpreg12mth_`i' == . & sr_whatmeth_avoidpreg12mth != 1
}
replace sr_meth_otherspec12mth = ".Not applicable" if sr_meth_otherspec12mth == "" & sr_meth_avoidpreg12mth_96 != 96



*************
** Section 9. CASI questionnaire

replace srs_agefirstsex = .n if srs_agefirstsex == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_agefirstsex = .n if srs_agefirstsex == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
replace srs_agefirstsex = 93 if srs_agefirstsex == . & (srs_share_agefirstsex == 2 | srs_share_agefirstsex == 93 ) 
replace srs_agefirstsex = 93 if srs_agefirstsex == .  	//  No screener in round 3; 9 skips in rounds 1 and 2
replace srs_agefirstsex = 16 if srs_agefirstsex == 1616
replace srs_agefirstsex = 16 if srs_agefirstsex == 1717 
replace srs_agefirstsex = 13 if srs_agefirstsex == 2014 // Birthday 20 Jan, so almost certinaly 13 in 2014
drop srs_share_agefirstsex
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 96 {
	replace srs_firstsexreas_`i' = .n if srs_firstsexreas_`i' == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
	replace srs_firstsexreas_`i' = .n if srs_firstsexreas_`i' == . & (sr_everpregnant != 1 & srs_everhadsex != 1)
}
replace srs_firstsexreas_oth = ".Not applicable" if srs_firstsexreas_oth == "" & srs_firstsexreas_96 != 96

qui ds srs_firstsexwho srs_firstsex_gift srs_firstsex_gift_fem srs_firstsex_preg srs_firstsex_hiv srs_firstsex_knwstatus
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & srs_agefirstsex == .n
}
replace srs_firstsex_gift = srs_firstsex_gift_fem if round > 1 & srs_firstsex_gift == .
drop srs_firstsex_gift_fem 
replace srs_firstsex_hiv = 1 if inlist(srs_firstsex_hivoth, "Kh0nd0m", "Ikhondom", "Ukusebenzisa ama condom", "Kuhlela condomise", "Use proctetion")
replace srs_firstsex_hivoth = ".Not applicable" if inlist(srs_firstsex_hivoth, "Kh0nd0m", "Ikhondom", "Ukusebenzisa ama condom", "Kuhlela condomise", "Use proctetion")
replace srs_firstsex_hivoth = ".Not applicable" if srs_firstsex_hivoth == "" & srs_firstsex_hiv != 96
replace srs_firstsex_statusis = .n if srs_firstsex_statusis == . & srs_firstsex_knwstatus != 1
replace srs_firstsex_useart = .n if srs_firstsex_useart == . & srs_firstsex_statusis != 1

replace srs_partnagefirstsex  = .d if srs_share_partnagefirstsex == 3
replace srs_partnagefirstsex  = 93 if srs_share_partnagefirstsex == 93 | srs_share_partnagefirstsex == 2
replace srs_partnagefirstsex  = .n if srs_partnagefirstsex  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_partnagefirstsex  = .n if srs_partnagefirstsex  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
replace srs_partnagefirstsex  = 93 if srs_partnagefirstsex == . & round == 3 
	// slight assumption that skip in round 3 (no 'share' question) is equivalent to PNTA
replace srs_partnagefirstsex  = 22 if srs_partnagefirstsex == 2216		// Aged 19 at interview, age of first sex was 16
drop srs_share_partnagefirstsex
replace srs_firstestmage = .n 	if srs_firstestmage == . & srs_partnagefirstsex != 3
replace srs_firstestmyears = .n if srs_firstestmyears == . & srs_partnagefirstsex != 3

replace srs_agesecondsex  = 93 if srs_share_agesecondsex == 93 | srs_share_agesecondsex == 2
replace srs_agesecondsex  = .n if srs_agesecondsex  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_agesecondsex  = .n if srs_agesecondsex  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
replace srs_agesecondsex  = .n if srs_agesecondsex  == . & srs_share_agesecondsex == 0 // Says no second partner
replace srs_agesecondsex  = 93 if srs_agesecondsex == . & round == 3 		
	// slight assumption that skip in round 3 (no 'share' question) is equivalent to PNTA
replace srs_agesecondsex = 18 if srs_agesecondsex == 1811111		// Presumed typo
replace srs_agesecondsex = 17 if srs_agesecondsex == 171			// Presumed typo
drop srs_share_agesecondsex

replace srs_life_numsexpartn  = 93 if srs_sharelife_numsexpartn == 93 | srs_sharelife_numsexpartn == 2
replace srs_life_numsexpartn  = 93 if srs_life_numsexpartn  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)		
replace srs_life_numsexpartn  = 0 if srs_life_numsexpartn  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )			
replace srs_life_numsexpartn  = 93 if srs_life_numsexpartn == . & round == 3 		
	// slight assumption that skip in round 3 (no 'share' question) is equivalent to PNTA
drop srs_sharelife_numsexpartn

replace srs_12mth_numsexpartn  = 93 if srs_share12mth_numsexpartn == 93 | srs_share12mth_numsexpartn == 2
replace srs_12mth_numsexpartn  = .n if srs_12mth_numsexpartn  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_12mth_numsexpartn  = .n if srs_12mth_numsexpartn  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
replace srs_12mth_numsexpartn  = 93 if srs_12mth_numsexpartn == . & round == 3 		
	// slight assumption that skip in round 3 (no 'share' question) is equivalent to PNTA
drop srs_share12mth_numsexpartn

replace srs_12mth_newsexpartn = ".Not applicable" if srs_12mth_newsexpartn == "" & (srs_12mth_numsexpartn > 0 | missing(srs_12mth_numsexpartn))
* Flag: sr_12mth_newsexpartn - text field poorly answered, needs cleaning

replace srs_numsexrelat  = 93 if srs_share_numsexrelat == 93 | srs_share_numsexrelat == 2
replace srs_numsexrelat  = .n if srs_numsexrelat  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_numsexrelat  = .n if srs_numsexrelat  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
drop srs_share_numsexrelat

replace srs_transsex_women  = .n if srs_transsex_women  == . & (sr_everpregnant == 1 & srs_everhadsex == 93 | pd_sex != 2)
replace srs_transsex_women  = .n if srs_transsex_women  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )

replace srs_transsex_num  = 93 if srs_share_transsex == 93 | srs_share_transsex == 2
replace srs_transsex_num  = .n if srs_transsex_num  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
replace srs_transsex_num  = .n if srs_transsex_num  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
replace srs_transsex_num  = 0 if srs_transsex_num  == . & srs_share_transsex == 0 // Says no transactional sex
drop 	srs_share_transsex

qui ds srs_sexworker srs_usecondom3months srs_usecondomlasttime srs_condomless_1month
foreach v in `r(varlist)' {
	replace `v' = .n if `v'  == . & (sr_everpregnant == 1 & srs_everhadsex == 93)
	replace `v' = .n if `v'  == . & (sr_everpregnant != 1 & srs_everhadsex != 1 )
}
replace srs_usecondom3months = 2 if srs_usecondom3months == 0		// Says no sex in past 3 months, so no condom
replace srs_condomless_1month = .n if srs_condomless_1month == . & round == 1		// Not asked round 1
replace srs_condomless12months = .n if srs_condomless12months == . & round == 1		// Not asked round 1
replace srs_condomless12months = .n if srs_condomless12months == . & srs_condomless_1month != 2

* FLAG: all srs_recnt1* are missing for round 3 - piping error
qui ds srs_recnt1_*, has(type numeric)
	foreach v in `r(varlist)' {
		replace `v' = .e if `v' == . & round == 3
	}
qui ds srs_recnt1_*, has(type string)
	foreach v in `r(varlist)' {
		replace `v' = ".Error - question not asked" if `v' == "" & round == 3
	}
* FLAG: All srs_rcnt* are only asked if srs_recnt*_sexin12mths == 1 
forvalues i = 1/3 {
	qui ds srs_recnt`i'*, has(type numeric)
	foreach v in `r(varlist)' {
		replace `v' = .n if `v' == . & (srs_12mth_numsexpartn < `i' | srs_12mth_numsexpartn > 89)
		if "`v'" != "srs_recnt`i'_sexin12mths" {
			replace `v' = .n if `v' == . & srs_recnt`i'_sexin12mths != 1
		}
	}
	qui ds srs_recnt`i'*, has(type string)
	foreach v in `r(varlist)' {
		replace `v' = ".Not applicable" if `v' == "" & (srs_12mth_numsexpartn < `i' | srs_12mth_numsexpartn > 89)
		replace `v' = ".Not applicable" if `v' == "" & srs_recnt`i'_sexin12mths != 1
	}	
}
forvalues i = 1/3 {
	foreach q in timeago lasttime {
		foreach r in `q' `q'unit {
			cap replace srs_recnt`i'_`r'		= srs_recnt`i'_share`q' if srs_recnt`i'_share`q' > 89 & srs_recnt`i'_share`q' < 100
			cap replace srs_recnt`i'_`r' 		= 93 if srs_recnt`i'_share`q' == 2  // 'No' to sharing === PNTA
		}
	}
	cap replace srs_recnt`i'_personage		= srs_recnt`i'_shareage if srs_recnt`i'_shareage > 89 & srs_recnt`i'_shareage < 100
	cap replace srs_recnt`i'_personage 		= 93 if srs_recnt`i'_shareage == 2  // 'No' to sharing === PNTA
	cap replace srs_recnt`i'_numsex4wks		= srs_recnt`i'_sharenumsex4wks if srs_recnt`i'_sharenumsex4wks > 89 & srs_recnt`i'_sharenumsex4wks < 100
	cap replace srs_recnt`i'_numsex4wks 	= .z if srs_recnt`i'_sharenumsex4wks == 95  

	replace srs_recnt`i'_isigodi 		= .n if srs_recnt`i'_isigodi == . & srs_recnt`i'_personreside != 3
	replace srs_recnt`i'_buylastcondom 	= .n if srs_recnt`i'_buylastcondom == . & srs_recnt`i'_lastconduse != 1
	replace srs_recnt`i'_whylastcondom 	= .n if srs_recnt`i'_whylastcondom == . & srs_recnt`i'_lastconduse != 2

	replace srs_recnt`i'_buyfirstcondom = .n if srs_recnt`i'_buyfirstcondom == . & srs_recnt`i'_firstconduse != 1
	replace srs_recnt`i'_whyfirstcondom = .n if srs_recnt`i'_whyfirstcondom == . & srs_recnt`i'_firstconduse != 2

	replace srs_recnt`i'_numsex4wks 	= .n if srs_recnt`i'_numsex4wks == . & (srs_12mth_numsexpartn < `i' | srs_12mth_numsexpartn > 89 | srs_recnt`i'_sexin12mths != 1)

	replace srs_recnt`i'_partnstatus 	= .n if srs_recnt`i'_partnstatus == . & srs_recnt`i'_knwpartnstatus != 1
	replace srs_recnt`i'_howknowstatus 	= .n if srs_recnt`i'_howknowstatus == . & srs_recnt`i'_knwpartnstatus != 1
	replace srs_recnt`i'_knowstat_oth 	= ".Not applicable" if srs_recnt`i'_knowstat_oth == "" & srs_recnt`i'_howknowstatus != 96

	replace srs_recnt`i'_partnstatus 	= 2 if srs_recnt`i'_partnstatus == 0	// coding error by Jaco - different from other pos/neg variables
	replace srs_recnt`i'_partnstatus 	= srs_recnt`i'_partnstatus - 1 if srs_recnt`i'_partnstatus < 9 
	
	replace srs_recnt`i'_partn_onart 	= .n if srs_recnt`i'_partn_onart == . & srs_recnt`i'_partnstatus != 2
	replace srs_recnt`i'_no_prepreas 	= .n if srs_recnt`i'_no_prepreas == . & srs_recnt`i'_takeprep != 2
		
	replace srs_recnt`i'_no_prepoth 	= ".Not applicable" if srs_recnt`i'_no_prepoth == "" & srs_recnt`i'_no_prepreas != 96
}
drop srs_recnt*_sharetimeago srs_recnt*_sharelasttime srs_recnt*_shareage srs_recnt*_sharenumsex4wks

* FLAG: srs_recnt*_personhivstatus only seems to exist for 3rd most recent partner - piping error?

* 12-month male violence only in round 3
qui ds srs_female_violen_12mths_*
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & round != 3 
}
qui ds srs_sasa_* 		// Requires ever had sex
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & 	srs_everhadsex != 1
}
qui ds srs_srpscale*		// Requires current relationship (in past 12 months)
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & (srs_12mth_numsexpartn == 0 | srs_12mth_numsexpartn > 89 | srs_recnt1_currelation > 2 | srs_recnt2_currelation > 2 | srs_recnt3_currelation > 2)
}

* DMD scale not in CASI
foreach v in srs_dmdscale02 srs_dmdscale07 srs_dmdscale08 {
	replace `v' = 80 if `v' == . & srs_everhadsex != 1 & round != 1
}

drop srs_sv_* 		// operational variables

replace srs_assisted_by = .n if round == 3 
recode 	srs_assisted_by 4=5 3=4 1=3
drop or_assisted_by



***********************************
*** Section 10. DBS blood sample

* Non-consenters after interview
qui ds dr_specim_collec-dr_target_clinicoth_out, has(type numeric)	
foreach v in `r(varlist)' {
	replace `v' = .c if `v' == . & ic_consent_hsv != 1
}
qui ds dr_specim_collec-dr_target_clinicoth_out, has(type string)	
foreach v in `r(varlist)' {
	replace `v' = ".No consent" if `v' == "" & ic_consent_hsv != 1
}
* No blood drawn - reason unclear
qui ds dr_test_name-dr_target_clinicoth_out, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & dr_specim_collec != 1
}
qui ds dr_test_name-dr_target_clinicoth_out, has(type string)
foreach v in `r(varlist)' {
	replace `v' = ".Not applicable" if `v' == "" & dr_specim_collec != 1
}

replace dr_hsv_test_result = .c if dr_hsv_test_result == . & ic_consent_hsv != 1
replace dr_hsv_test_result = .n if dr_hsv_test_result == . & dr_specim_collec != 1

* replace dr_hiv_test_result = .c if dr_hiv_test_result == . & ic_consent_hiv != 1
replace dr_hiv_test_result = .n if dr_hiv_test_result == . & dr_specim_collec != 1
replace dr_hiv_test_result = 0 if dr_hiv_test_result  == 2			// 5 indeterminate tests to not-positive
lab def lblPartHIVStatus 9 Indeterminate , modify

* Back-impute values from round 3 negatives; forward from earlier positives
sort IIntId round
bys IIntId: replace dr_hiv_test_result = 0 if dr_hiv_test_result == . & round[_n+1] == 3 & dr_hiv_test_result[_n+1] == 0
bys IIntId: replace dr_hiv_test_result = 0 if dr_hiv_test_result == . & round[_n+2] == 3 & dr_hiv_test_result[_n+2] == 0
bys IIntId: replace dr_hiv_test_result = 0 if dr_hiv_test_result == . & round[_n+1] == 2 & dr_hiv_test_result[_n+1] == 0
bys IIntId: replace dr_hiv_test_result = 1 if dr_hiv_test_result == . & round[_n-1] == 1 & dr_hiv_test_result[_n-1] == 1
bys IIntId: replace dr_hiv_test_result = 1 if dr_hiv_test_result == . & round[_n-1] == 2 & dr_hiv_test_result[_n-1] == 1
replace dr_hiv_test_result = .e if IIntId == 87397 & round == 2 & dr_hiv_test_result == . // Insufficient blood for test

replace dr_target_clinicdate = .n if dr_target_clinicdate == . & dr_refer_clinic != 1
replace dr_target_clinicname = ".Not applicable" if dr_target_clinicname == "" & dr_refer_clinic != 1
replace dr_target_clinicoth_in = ".Not applicable" if dr_target_clinicoth_in == "" & strpos(dr_target_clinicname, "Other place inside") == 0
replace dr_target_clinicoth_out = ".Not applicable" if dr_target_clinicoth_out == "" & strpos(dr_target_clinicname, "Other place inside") == 0



********************************************
*** Section 11. Rapid HIV test (round 3 only)

replace hr_rapidtest_done = .c if hr_rapidtest_done == . & ic_consent_hiv != 1
replace hr_no_rapidtest_reas = ".Not applicable" if hr_no_rapidtest_reas == "" & hr_rapidtest_done != 2

qui ds mh_*, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & hr_rapidtest_done != 1
}
qui ds mh_*, has(type string)
foreach v in `r(varlist)' {
	replace `v' = ".No consent" if `v' == "" & ic_consent_interv == 2		
	replace `v' = ".Not applicable" if `v' == "" & hr_rapidtest_done != 1
}

replace mh_rapidscreen_result = mh_rapidscreen_result_rep if mh_rapidscreen_result == 3 	// 2 cases 
replace mh_rapidconf1_result = mh_rapidconf1_result_rep if mh_rapidconf1_result == 3		// no cases
replace mh_rapidscreen_result_rep = .n if mh_rapidscreen_result_rep == . & mh_rapidscreen_result != 3
replace mh_rapidconf1_result_rep = .n if mh_rapidconf1_result_rep == . & (mh_rapidconf1_result != 3 | mh_rapidscreen_result_rep == 3)

* No-one referred to mobile clinic
replace mh_refer_mobile_reason = ".Not applicable" if mh_refer_mobile_reason == "" & mh_refer_mobile_clinic != 1

* mh_elisa section entirely empty - not used for this cohort - dropped in iecodebook

qui ds mh_attends_clinic-$lastvar, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .n if `v' == . & mh_rapidtest_result != 1
} 
qui ds mh_attends_clinic-$lastvar, has(type string)
foreach v in `r(varlist)' {
	replace `v' = ".Not applicable" if `v' == "" & mh_rapidtest_result != 1
} 

replace mh_target_clinicoth_in = ".Not applicable" if mh_target_clinicoth_in == "" & strpos(mh_target_clinicname, "Other place inside") == 0
replace mh_target_clinicoth_out = ".Not applicable" if mh_target_clinicoth_out == "" & strpos(mh_target_clinicname, "Other place inside") == 0

* drop technical details
drop mh_rapidscreen_testtype mh_rapidscreen_lotnum mh_rapidscreen_lotnum_rep mh_rapidscreen_result_rep ///
	mh_rapidconf1_testtype mh_rapidconf1_lotnum mh_rapidconf1_lotnum_rep mh_rapidconf1_result_rep


* Tidy all questions affected by pd_sex errors
gen 	c_pd_sex_flag = 2 if pd_sex == 2
replace	c_pd_sex_flag = 1 if c_pd_sex_flag == .
lab def flagf 2 "No flag" 1 "Flag for variable"
lab val	c_pd_sex_flag flagf
lab var c_pd_sex_flag "Flag for non-female preloaded sex"

qui ds dm_*safespace* dm_*emercon* mv_borrmoney_fem-mv_knowguard_fem ///
	sr_currpregnant-sr_meth_otherspec12mth srs_transsex_women srs_sexworker srs_female_violence*, ///
	has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .e if (`v' == . | `v' == .n) & c_pd_sex_flag == 1
}

** Apply codebook and reorder

iecodebook apply using "$outLoc/codebook_dreams_30Jul2020.xlsx"
drop pd_dob				// identifiability issue
order mv_mob_trip_number mv_mob_last_* mv_mob_long_*, after(mv_mob_moved)



*** Final tidying
cap drop tmp*

* Final reordering:
order ca_staffname, after(ca_visitdate)
order ms_talked_to_who_2, after(ms_talked_to_who_1)
order hq_prep_struggle_4, after(hq_prep_struggle_3)
order hq_prep_struggle_5, after(hq_prep_struggle_4)
order hq_prep_struggle_7, after(hq_prep_struggle_6)
order hq_prep_struggle_8, after(hq_prep_struggle_7)
order hq_prep_struggle_96, after(hq_prep_struggle_8)
order sr_cntra_now_mthd_4, after(sr_cntra_now_mthd_3)
order sr_cntra_12m_mthd_4, after(sr_cntra_12m_mthd_3)

* Tidying missingness codes to missing values
qui ds, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = .p if `v' == 93
	replace `v' = .d if `v' == 98 | `v' == 90
	replace `v' = .n if `v' == 97
	
}
* Add missing codes to all label lists
qui lab dir
foreach v in `r(names)' {
	lab def `v' .p "Prefer not to answer" .d "Don't know" .n "Question not applicable" .c "Consent not given" .r "Question not in round" .e "Error - question not asked", modify
}
* Add labels to all numerics without a label at present (should only be count variables)
qui ds ie_inschool-$lastvar, not(vallabel)		// TODO: Check if final variable has changed
local nolabs `r(varlist)'
qui ds , has(type numeric)
local numer `r(varlist)'
local varlist : list nolabs & numer
foreach v in `varlist' {
	lab val `v' numericf
}




********************************************************************************
*** 	Creating new variables
********************************************************************************

**********************************
** DREAMS interventions categories
cls

*** Fix DREAMS categories that change over time:

/* Code to check on DREAMS variable sets
	cls
	qui ds dm_aware*
	foreach v in `r(varlist)' {
		di "`v'"
		tab `v' round, miss
	}

New in R2:
	faclbase: rename of hivtest from R1
	finskill: finlitera + vocatskill
	democond: truly new in 2018
	finserv:  savegroup + microfin 							
	pepserv:  In R1, only in hq_pep*; in R2/R3, in dm_* and hq_*
	
	Other merges in R2:
	cashtran: cashagyw + cashtran (family) + schoolsup
	hivtest:  mobiletest + hometest + familytest
	genorm:   genorm + dm_*violprevnt* (comm) + *violprev_* (schools)  		
	
	Dropped in R2:
	shuga
	linkart   		- dropped from dm - see hq
	artadhere      - dropped from dm - see hq
	
	New in R3:
	thethana
*/


* Flag: no adjustments made for "other provider" values

ds *faclbase*
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 8)
	replace `v' = `stub'hivtest if round == 1
}
ds *finskill*, has(type numeric)
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 8)
	replace `v' = . if round == 1
	replace `v' = 1 if (`stub'finlit == 1 | `stub'vocatskill == 1) & round == 1
	replace `v' = 2 if (`stub'finlit == 2 | `stub'vocatskill == 2) & round == 1 & `v' == .
	replace `v' = .n if (`stub'finlit == .n | `stub'vocatskill == .n) & round == 1 & `v' == .
	replace `v' = .c if (`stub'finlit == .c | `stub'vocatskill == .c) & round == 1 & `v' == .
}
ds *finserv*, has(type numeric)
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 7)
	replace `v' = . if round == 1
	replace `v' = 1 if (`stub'savegrp == 1 | `stub'microfin == 1) & round == 1
	replace `v' = 2 if (`stub'savegrp == 2 | `stub'microfin == 2) & round == 1 & `v' == .
	replace `v' = .n if (`stub'savegrp == .n | `stub'microfin == .n) & round == 1 & `v' == .
	replace `v' = .c if (`stub'savegrp == .c | `stub'microfin == .c) & round == 1 & `v' == .	
}
ds *cashtran*, has(type numeric)
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 8)
	clonevar	`v'_original = `v'
	replace `v' = 1 if (`stub'cashagyw == 1 | `stub'schoolsup == 1) & round == 1 & (`v' == 2 | missing(`v' ))
}
ds *hivtest*, has(type numeric)
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 7)
	clonevar	`v'_original = `v'
	replace `v' = 1 if (`stub'mobiletest == 1 | `stub'hometest == 1 | `stub'familytest == 1) & round == 1 & (`v' == 2 | missing(`v' ))
}
ds *genorm*, has(type numeric)
foreach v in `r(varlist)' {
	local stub = substr("`v'", 1, length("`v'") - 6)
	clonevar	`v'_original = `v'
	replace `v' = 1 if (`stub'violprevsch == 1 | `stub'violprevcom == 1) & round == 1 & (`v' == 2 | missing(`v' ))
}

*** Loop to build categories and levels:

/* Example : 1. Awareness of any intervention in the category

global var_stem "social_asset"
global var_name "Social assets"
global iv_lista "dm_aware_safespace dm_aware_mentor dm_aware_socassets"
global iv_listu "dm_part12m_safespace dm_part12m_mentor dm_part12m_socassets"

global var_stem "community_mobilize" 
global var_name	"Community mobilization services" 
global iv_lista	"dm_aware_genorm" 
global iv_listu	"dm_part12m_genorm"

cap drop 	c_dm_aware_$var_stem
gen 		c_dm_aware_$var_stem = 2
foreach var in $iv_lista {
	replace c_dm_aware_$var_stem = 1 if `var' == 1 
	replace c_dm_aware_$var_stem = `var' if `var' == .c | `var' == .n 		// Question never asked
	* replace c_dm_aware_$var_stem = . if `var' == .p | `var' == .			// For now, treat skips as 'not-yes'
}
lab val 	c_dm_aware_$var_stem lblYesNo
lab var 	c_dm_aware_$var_stem "Any awareness of $var_name interventions"

* 2. Usage of any intervention in the category
cap drop 	c_dm_use_$var_stem
gen 		c_dm_use_$var_stem = . 
foreach var in $iv_listu {
	replace c_dm_use_$var_stem  = 1 if `var' == 1 
	replace c_dm_use_$var_stem  = 2 if c_dm_aware_$var_stem == 2 			// Assume have to be aware to use
	replace c_dm_use_$var_stem  = 2 if c_dm_use_$var_stem == . & !missing(`var')
	replace c_dm_use_$var_stem  = `var' if `var' == .c | `var' == .n
}
lab val 	c_dm_use_$var_stem lblYesNo
lab var 	c_dm_use_$var_stem "Any use of $var_name interventions"

*  3. Count of interventions of which AGYW are aware of 
cap drop 	c_dm_caware_$var_stem
egen 		c_dm_caware_$var_stem = anycount($iv_lista), v(1)
replace		c_dm_caware_$var_stem = c_dm_aware_$var_stem if missing(c_dm_aware_$var_stem)
lab val 	c_dm_caware_$var_stem numericf
lab var 	c_dm_caware_$var_stem "Count of awareness of $var_name interventions"

* 4. Count of interventions of which AGYW have participated in
cap drop 	c_dm_cuse_$var_stem
egen 		c_dm_cuse_$var_stem = anycount($iv_listu), v(1)
replace		c_dm_cuse_$var_stem = c_dm_use_$var_stem if missing(c_dm_use_$var_stem)
lab val 	c_dm_cuse_$var_stem numericf
lab var 	c_dm_cuse_$var_stem "Count of use of $var_name interventions"
*/

** Build a programme to loop over sets of variables:
	
cap prog drop dreams_build 
prog def dreams_build 

	/* Required info: 
		1. Output variable stem
		2. Output variable name
		3. Input variables for awareness		
		4. Input variables for use
	*/

	cap drop 	c_dm_aware_`1'
	gen 		c_dm_aware_`1' = 2
	foreach var in `3' {
		replace c_dm_aware_`1' = 1 if `var' == 1 
		replace c_dm_aware_`1' = `var' if `var' == .c | `var' == .n 		// Question never asked
		* replace c_dm_aware_`1' = . if `var' == .p | `var' == .			// For now, treat skips as 'not-yes'
	}
	foreach var in `3' {
		replace c_dm_aware_`1' = . if c_dm_aware_`1' == 0 & (missing(`var') | `var' > 91)
	}
	lab val 	c_dm_aware_`1' lblYesNo
	lab var 	c_dm_aware_`1' "Any awareness of `2' interventions"

	* 2. Usage of any intervention in the category
	cap drop 	c_dm_use_`1'
	gen 		c_dm_use_`1' = . 
	foreach var in `4' {
		replace c_dm_use_`1' = 1 if `var' == 1 
		replace c_dm_use_`1' = 2 if c_dm_aware_`1'== 2 			// Assume have to be aware to use
		replace c_dm_use_`1' = 2 if c_dm_use_`1'== . & !missing(`var')
		replace c_dm_use_`1' = `var' if `var' == .c | `var' == .n
	}
	lab val 	c_dm_use_`1' lblYesNo
	lab var 	c_dm_use_`1' "Any use of `2' interventions"

	*  3. Count of interventions of which AGYW are aware of 
	cap drop 	c_dm_caware_`1'
	egen 		c_dm_caware_`1' = anycount(`3'), v(1)
	replace		c_dm_caware_`1' = c_dm_aware_`1' if missing(c_dm_aware_`1')
	lab val 	c_dm_caware_`1' numericf
	lab var 	c_dm_caware_`1' "Count of awareness of `2' interventions"
	
	* 4. Count of interventions of which AGYW have participated in
	cap drop 	c_dm_cuse_`1'
	egen 		c_dm_cuse_`1' = anycount(`4'), v(1)
	replace		c_dm_cuse_`1' = c_dm_use_`1' if missing(c_dm_use_`1')
	lab val 	c_dm_cuse_`1' numericf
	lab var 	c_dm_cuse_`1' "Count of use of `2' interventions"

  end 
   
#delimit ;   

** A. EMPOWER AGYW AND REDUCE THEIR RISK OF HIV ;
* 1. Social assets (3 items);
dreams_build 
	"social_asset" 
	"Social assets (Category 1)" 
	"dm_aware_safespace dm_aware_mentor dm_aware_socassets"
	"dm_part12m_safespace dm_part12m_mentor dm_part12m_socassets"
; 

* 2. HIV testing and counselling among those sexually active (6 items in 3 variables) ; 
dreams_build 
	"hiv_test_couns" 
	"HIV testing & counselling (Category 2)" 
	"dm_aware_hivtest dm_aware_faclbase dm_aware_selftest dm_aware_partest" 
	"dm_part12m_hivtest dm_part12m_faclbase dm_part12m_selftest dm_part12m_partest" 
;   // Dropped linkart and artadhere - only asked in baseline
	// No pepserv - not asked in R1
	// hivtest includes mobiletest, hometest & familytest 

* 3. Expand contraceptive mix methods (3 items) ;		
dreams_build 
	"contra_expand" 
	"Expanded contraceptive method mix (Category 3)" 
	"dm_aware_contracounsl dm_aware_adolfriend dm_aware_emercon" 
	"dm_part12m_contracounsl dm_part12m_adolfriend dm_part12m_emercon"
;

* 4. Post-violence care (1 item) ;
dreams_build 
	"postviolence" 
	"Post-violence care (Category 4)" 
	"dm_aware_postviol" 
	"dm_part12m_postviol"
;

* 5. Condom promotion (2 items) ;
dreams_build 
	"condom_prov" 
	"Condom promotion and provision (Category 5)" 
	"dm_aware_condprov dm_aware_democond" 
	"dm_part12m_condprov dm_part12m_democond"
;

* Total A. EMPOWERMENT OF YOUNG WOMEN (15 items in 12 variables) ;
dreams_build 
	"pkg_empower_agyw" 
	"AGYW empowerment activities (Package A)" 
	"c_dm_aware_social_asset c_dm_aware_hiv_test_couns c_dm_aware_contra_expand c_dm_aware_postviolence c_dm_aware_condom_prov" 
	"c_dm_use_social_asset c_dm_use_hiv_test_couns c_dm_use_contra_expand c_dm_use_postviolence c_dm_use_condom_prov"
;


** B. MOBILIZE COMMUNITY FOR CHANGE ;
* 6. Community mobilization (3 items in one variable) ;
# delimit ;
dreams_build 
	"gender_norms"  
	"Gender norms interventions (Category 6)"
	"dm_aware_genorm" 
	"dm_part12m_genorm"
;	// Add in school-based violence prevention (bc merged in 2018/19)
	// genorm:  genorm + dm_*violprevnt* (comm) + *violprev_* (schools)  
	
# delimit ;
* 7. School-based HIV prevention education (1 item) ;		
dreams_build 
	"school_hiv_edu" 
	"School-based HIV education (Category 7)" 
	" dm_aware_schoolhivedu" 
	" dm_part12m_schoolhivedu"
;		// Cannot include school violence prevention now

/* 
* Code to make 'no' if not in school - not asked to these people in R1 and R3 ;
# delimit cr
qui ds *school_hiv_edu 		
foreach v in `r(varlist)' {
	replace `v' = 2 if `v' == .n & ie_inschool != 1
}
*/		
/*
#delimit cr
* Code to make only relevant to those in school - leave for individuals to code if wanted
qui ds *school_hiv_edu 		
foreach v in `r(varlist)' {
	replace `v' = .n if `v' != .c & ie_inschool != 1
}
*/

# delimit ;
* B Total. MOBILIZE COMMUNITY/NORMS CHANGE (4 items in 2 variables) ;
dreams_build 
	"pkg_community_norms" 
	"Community norms (Package B)" 
	"c_dm_aware_gender_norms c_dm_aware_school_hiv_edu" 
	"c_dm_use_gender_norms c_dm_use_school_hiv_edu"
;

** C. STRENGHTEN FAMILIES -					
# delimit ;

* 8. Social protection (7 items in 3 variables) ;
dreams_build 
	"social_protection" 
	"Social protection (Category 8)" 
	" dm_aware_finskill dm_aware_finserv dm_aware_cashtran" 
	" dm_part12m_finskill dm_part12m_finserv dm_part12m_cashtran"
;   // finskill =  finlitera + vocatskill
	// finserv = savegroup + microfin 							
	// cashtran =  cashagyw + cashtran + schoolsup

* 9. Parenting and caregiver programme (1 item) ;
dreams_build 
	"parent_caregiver" 
	"Parenting/caregiver programme (Category 9)" 
	"dm_aware_parentcare" 
	"dm_part12m_parentcare"
;
# delimit ;

* C Total. STREHGTHEN FAMILIES (8 items in 4 variables) ;
dreams_build 
	"pkg_strengthen_famil" 
	"Strengthen families (Package C)" 
	"c_dm_aware_social_protection c_dm_aware_parent_caregiver" 
	"c_dm_use_social_protection c_dm_use_parent_caregiver"
;

# delimit cr


/* 
	Future work: Manage skipped/PNTA in grouped data - currently treated as 'not yes'
	3 levels: yes, no, at least one missing
*/
/* 	
	Future work: Create as c_dm_*
		3-level variable: DREAMS, non-DREAMS, no
		4 variables: package and level, PEPFAR and AHRI [unclear how this last works]
*/




*********************************
*** Creating additional variables:

* Grant receipt:
* Flag: child grants asked differently across waves
*      Child support for self and others highly confounded

* Create variable capturing any grant of any kind received
gen 	c_ie_grant_any = 1 if ((ie_granttype == 1 | ie_granttype == 3 | ie_granttype == 5 | ie_granttype == 96) & round == 1)		// wave 1 only
replace	c_ie_grant_any = ie_granttype if ie_granttype == 2 | (missing(ie_granttype) & round == 1)
foreach i in 1 3 4 6 96 {
	replace c_ie_grant_any = 1 if c_ie_grant_any == . & ie_granttype_`i' == 1 
}
replace c_ie_grant_any = ie_granttype_1 if c_ie_grant_any == . & missing(ie_granttype_1) & round != 1
replace c_ie_grant_any = 2 if c_ie_grant_any == . & (ie_granttype_2 == 1 | ie_granttype_2 == 2)
lab val c_ie_grant_any lblYesNo
lab var c_ie_grant_any "Received any govenment grant - Q change after R1"

* Wealth index:
pca ie_items_own* 		
* First component loads on school items only (items 3 and 5); drop these two items
pca ie_items_own01 ie_items_own02 ie_items_own04 ie_items_own06 ///
	ie_items_own07 ie_items_own08 ie_items_own09 ie_items_own10 
* Now one component seems reasonable, captures 
predict	c_ie_item_pca
xtile 	c_ie_item_pca_cat = c_ie_item_pca, nq(5)
lab var c_ie_item_pca "Wealth PCA based on 8 non-school items"
lab var c_ie_item_pca_cat "Wealth PCA quintiles based on 8 non-school items"

* Merge education variables from in/out of school - PREFERRED MEASURE
gen 	c_ie_educ_lvl = 1 if ie_highlevledu == 0 | ie_highlevled == 1 | ie_schoolgrade <= 7    /*not completed primary*/
replace c_ie_educ_lvl = 2 if (ie_schoolgrade >= 8 & ie_schoolgrade <= 12) | (ie_highlevled==2) /*Not completed secondary*/
replace c_ie_educ_lvl = 3 if ie_highlevled == 3 /*Completed secondary*/
replace c_ie_educ_lvl = 4 if ie_highlevled >= 4 & ie_highlevled <= 6  /*Any tertiary*/
lab def lblEdu4  1 "None or Some primary" 2 "Some secondary" 3 "Completed secondary"  4 "Any tertiary" 
lab val c_ie_educ_lvl lblEdu4
lab var c_ie_educ_lvl  "Highest educational attainment (four categories)"

* Simplified employment
gen 	c_ie_employ_bin = ie_employed 
replace c_ie_employ_bin = 1 if ie_employed == 1 | ie_employed == 3
lab val c_ie_employ_bin lblYesNo
lab var c_ie_employ_bin "Currently employed (full or part time)"


* Lifetime sexual activity and pregnancy status

cap drop c_srs_sex_preg_ever
gen 	c_srs_sex_preg_ever = 2 if srs_sex_ever == 2 
replace c_srs_sex_preg_ever = 3 if srs_sex_ever == 1 & sr_preg_current == 2 & sr_preg_ever == 2
replace c_srs_sex_preg_ever = 4 if sr_preg_current == 1 | sr_preg_ever == 1
replace c_srs_sex_preg_ever = .c if sr_preg_ever == .c
replace c_srs_sex_preg_ever = 9 if c_srs_sex_preg_ever == .
lab def sexpregf 2 "Never had sex" 3 "Ever sex, never pregnant" 4 "Ever pregnant" 9 "Unknown" 
lab val c_srs_sex_preg_ever sexpregf
lab var c_srs_sex_preg_ever  "Ever had sex, ever pregnant composite variable"

* Past 12 months sexual activity and pregnancy status
cap drop c_srs_sex_preg_12m
gen 	c_srs_sex_preg_12m = 2 if srs_sex_ever == 2 
replace c_srs_sex_preg_12m = 3 if srs_sex_ever == 1 & srs_sex_12m_part_num == 0 & sr_preg_current == 2 & sr_preg_ever == 2  
replace c_srs_sex_preg_12m = 4 if srs_sex_ever == 1 & srs_sex_12m_part_num > 0 & !missing(srs_sex_12m_part_num) & sr_preg_current == 2 & sr_preg_ever == 2  
replace c_srs_sex_preg_12m = 5 if sr_preg_current == 1 | sr_preg_ever == 1
replace c_srs_sex_preg_12m = .c if sr_preg_ever == .c
replace c_srs_sex_preg_12m = 9 if c_srs_sex_preg_ever == .
lab def sexpreg2f 2 "Never had sex" 3 "Not sexually active, never pregnant" 4 "Sexually active, never pregnant" 5 "Ever pregnant" 9 "Unknown"  
lab val c_srs_sex_preg_12m sexpreg2f
lab var c_srs_sex_preg_12m "Sexually active past 12m, ever pregnant composite variable"


* srs_sex_12m_part_new: was asked as text field, tidy as far as possible:
gen 	c_srs_sex_12m_part_new = .
replace c_srs_sex_12m_part_new = .c if srs_sex_12m_part_new == ".No consent"
replace c_srs_sex_12m_part_new = .n if srs_sex_12m_part_new == ".Not applicable"
replace c_srs_sex_12m_part_new = .e if srs_sex_12m_part_new == ""
replace c_srs_sex_12m_part_new = 0  if srs_sex_12m_part_new == "0" | srs_sex_12m_part_new == "Abekh0" | srs_sex_12m_part_new == "Akekho" | srs_sex_12m_part_new == "August" | srs_sex_12m_part_new == "Cha" | srs_sex_12m_part_new == "N0" | srs_sex_12m_part_new == "N0n" | srs_sex_12m_part_new == "None" | srs_sex_12m_part_new == "O"
replace c_srs_sex_12m_part_new = 1  if srs_sex_12m_part_new == "1" | srs_sex_12m_part_new == "01"
foreach val in 2 3 4 5 6 {
	replace c_srs_sex_12m_part_new = `val'  if srs_sex_12m_part_new == "`val'" 
}
replace c_srs_sex_12m_part_new = 1 if srs_sex_12m_part_num == 1 & c_srs_sex_12m_part_new == .
replace c_srs_sex_12m_part_new = 1 if (srs_sex_12m_part_num == 2 & (srs_sex_12m_part_new == "11" | srs_sex_12m_part_new == "111")) & c_srs_sex_12m_part_new == .	// Heavy fingers
replace c_srs_sex_12m_part_new = 16 if srs_sex_12m_part_num == 17 & srs_sex_12m_part_new == "16" & c_srs_sex_12m_part_new == .
* Three people left: 2 partner + "yebo"; 2 partners + "They w" ; 4 partners + "57"
lab val c_srs_sex_12m_part_new numericf
lab var c_srs_sex_12m_part_new "Past 12 months number of new sexual partners; tidied"

* Common mental disorders using Shona Symtoms Questionnaire
cap drop 	c_mv_ssq_*
egen 		c_mv_ssq_count = anycount(mv_ssq_1-mv_ssq_14), v(1)
egen 		tmp = rmiss2(mv_ssq*)
replace 	c_mv_ssq_count = . if tmp == 14		// Treat those saying 'dont know' as present and saying 'no'
drop tmp
recode 		c_mv_ssq_count (1/8=0 "No") (9/max=1 "Yes"), gen(c_mv_ssq_binary)
replace 	c_mv_ssq_count = mv_ssq_1 if c_mv_ssq_count == .
replace 	c_mv_ssq_binary = mv_ssq_1 if c_mv_ssq_binary == .
lab var 	c_mv_ssq_count 	"SSQ-14 number of affirmative responses"
lab var 	c_mv_ssq_binary "SSQ-14 binary outcome: 9+ screens positive"


* TODO: How to summarize GOALS scale?
* Response options for mv_goals* are strange - TODO: reorder to make sense
* TODO: How to summarize 'Chance to Achieve' scale?
* TODO: How to recode all the SE scales?
* TODO: How to recode Hope scale
* TODO: How to recode Youth importance scale
* TODO: How to recode happiness questions
* TODO: How to recode life satisfaction scale


******************************************


* TODO: Flag throughout for pd_sex in wave 1 for the 16 non-women - search for pd_sex in codebook
* Flag: skip for pd_sex in W1 for dm: cashagyw postviolcare contraemerg finlitera safespaces 


save "$datLoc/dreams_agyw_cleaned_06Aug2020.dta", replace
